@@ -25,18 +25,41 @@ ob <- orderbook(file = filename)
 # read 5000 orders
 ob <- read.orders(ob, 5000)
 
-stopifnot(isTRUE(identical(test, ob@current.ob)))
+# 64bit machines will have the data frame in a different order than
+# 32bit machines, so a direct call to identical won't work. This
+# doesn't matter for any of the functions, so is not a problem.
+
+test <- test[order(test$id),]
+rownames(test) <- NULL
+
+temp <- ob@current.ob[order(ob@current.ob$id),]
+rownames(temp) <- NULL
+
+stopifnot(isTRUE(identical(test, temp)))
 
 
 # go back 5 orders and then forward 5 orders
 ob <- read.orders(ob, -5)
 ob <- read.orders(ob, 5)
 
-stopifnot(isTRUE(identical(test, ob@current.ob)))
+test <- test[order(test$id),]
+rownames(test) <- NULL
+
+temp <- ob@current.ob[order(ob@current.ob$id),]
+rownames(temp) <- NULL
+
+stopifnot(isTRUE(identical(test, temp)))
 
 ## Read time, should take us to 4981 orders
 
 ob <- read.time(ob, "9:32:11")
 ob <- read.orders(ob, 18)
 
-stopifnot(isTRUE(identical(test, ob@current.ob)))
+test <- test[order(test$id),]
+rownames(test) <- NULL
+
+temp <- ob@current.ob[order(ob@current.ob$id),]
+rownames(temp) <- NULL
+
+stopifnot(isTRUE(identical(test, temp)))
+
